@@ -39,9 +39,11 @@ using KeePassLib.Utility;
 
 namespace KeePass.App.Configuration
 {
-	[XmlType(TypeName = "Configuration")]
+	[XmlType(TypeName = AppConfigEx.StrXmlTypeName)]
 	public sealed class AppConfigEx
 	{
+		private const string StrXmlTypeName = "Configuration";
+
 		public AppConfigEx()
 		{
 		}
@@ -294,10 +296,11 @@ namespace KeePass.App.Configuration
 				this.Security.MasterKeyOnSecureDesktop = false;
 
 				AceIntegration aceInt = this.Integration;
-				aceInt.HotKeyGlobalAutoType = (ulong)Keys.None;
-				aceInt.HotKeyGlobalAutoTypePassword = (ulong)Keys.None;
-				aceInt.HotKeySelectedAutoType = (ulong)Keys.None;
-				aceInt.HotKeyShowWindow = (ulong)Keys.None;
+				aceInt.HotKeyGlobalAutoType = (long)Keys.None;
+				aceInt.HotKeyGlobalAutoTypePassword = (long)Keys.None;
+				aceInt.HotKeySelectedAutoType = (long)Keys.None;
+				aceInt.HotKeyShowWindow = (long)Keys.None;
+				aceInt.HotKeyEntryMenu = (long)Keys.None;
 			}
 
 			if(MonoWorkarounds.IsRequired(1378))
@@ -450,7 +453,7 @@ namespace KeePass.App.Configuration
 
 				return strArray;
 			};
-			GAction<AceFont> fFont = delegate(AceFont f)
+			Action<AceFont> fFont = delegate(AceFont f)
 			{
 				if(f == null) { Debug.Assert(false); return; }
 
@@ -509,7 +512,11 @@ namespace KeePass.App.Configuration
 			string strXPath = strPre + strProp;
 
 			XmlNode xn = xdEnforced.SelectSingleNode(strXPath);
-			return (xn != null);
+			if(xn == null) return false;
+
+			XmContext ctx = new XmContext(null, AppConfigEx.GetNodeOptions,
+				AppConfigEx.GetNodeKey);
+			return XmlUtil.IsAlwaysEnforced(xn, strXPath, ctx);
 		}
 
 		public static bool IsOptionEnforced(object pContainer, string strPropertyName)
@@ -548,6 +555,121 @@ namespace KeePass.App.Configuration
 			if((f & AceApplyFlags.FileTransactions) != AceApplyFlags.None)
 				FileTransactionEx.ExtraSafe = aceApp.FileTxExtra;
 		}
+
+		internal static void GetNodeOptions(XmNodeOptions o, string strXPath)
+		{
+			if(o == null) { Debug.Assert(false); return; }
+			if(string.IsNullOrEmpty(strXPath)) { Debug.Assert(false); return; }
+			Debug.Assert(strXPath.IndexOf('[') < 0);
+
+			switch(strXPath)
+			{
+				// Sync. with documentation
+
+				case "/Configuration/Application/PluginCompatibility":
+				case "/Configuration/Meta/DpiFactorX":
+				case "/Configuration/Meta/DpiFactorY":
+					o.NodeMode = XmNodeMode.None;
+					break;
+
+				case "/Configuration/Application/TriggerSystem/Triggers/Trigger":
+				case "/Configuration/Defaults/KeySources/Association":
+				case "/Configuration/PasswordGenerator/AutoGeneratedPasswordsProfile":
+				case "/Configuration/PasswordGenerator/LastUsedProfile":
+				case "/Configuration/PasswordGenerator/UserProfiles/Profile":
+					o.ContentMode = XmContentMode.Replace;
+					break;
+
+				// Nodes that do not have child elements:
+				// case "/Configuration/Application/WorkingDirectories/Item":
+				// case "/Configuration/Integration/AutoTypeAbortOnWindows/Window":
+
+				// Nodes where the mode 'Merge' may be more useful:
+				// case "/Configuration/Application/MostRecentlyUsed/Items/ConnectionInfo":
+				//     (allow users to save credentials)
+				// case "/Configuration/Custom/Item":
+				//     (empty Value explicitly only)
+				// case "/Configuration/Defaults/SearchParameters":
+				//     (admin might only want to turn off case-sensitivity)
+				// case "/Configuration/Integration/UrlSchemeOverrides/CustomOverrides/Override":
+				//     (allow users to enable/disable the item)
+				// case "/Configuration/MainWindow/EntryListColumnCollection/Column":
+				//     (allow users to change the width)
+
+				default: break;
+			}
+		}
+
+		internal static string GetNodeKey(XmlNode xn, string strXPath)
+		{
+			if(xn == null) { Debug.Assert(false); return null; }
+			if(string.IsNullOrEmpty(strXPath)) { Debug.Assert(false); return null; }
+
+			Debug.Assert(xn is XmlElement);
+			Debug.Assert((strXPath == xn.Name) || strXPath.EndsWith("/" + xn.Name));
+			Debug.Assert(strXPath.IndexOf('[') < 0);
+
+			string strA = null, strB = null;
+			switch(strXPath)
+			{
+				// Sync. with documentation
+
+				case "/Configuration/Application/PluginCompatibility/Item":
+				case "/Configuration/Application/WorkingDirectories/Item":
+				case "/Configuration/Integration/AutoTypeAbortOnWindows/Window":
+					strA = XmlUtil.SafeInnerXml(xn);
+					break;
+
+				case "/Configuration/Application/MostRecentlyUsed/Items/ConnectionInfo":
+					strA = XmlUtil.SafeInnerXml(xn, "Path");
+					strB = XmlUtil.SafeInnerXml(xn, "UserName"); // Cf. MRU display name
+					break;
+
+				case "/Configuration/Application/TriggerSystem/Triggers/Trigger":
+					strA = XmlUtil.SafeInnerXml(xn, "Guid");
+					break;
+
+				case "/Configuration/Custom/Item":
+					strA = XmlUtil.SafeInnerXml(xn, "Key");
+					break;
+
+				case "/Configuration/Defaults/KeySources/Association":
+					strA = XmlUtil.SafeInnerXml(xn, "DatabasePath");
+					break;
+
+				case "/Configuration/Integration/UrlSchemeOverrides/CustomOverrides/Override":
+					strA = XmlUtil.SafeInnerXml(xn, "Scheme");
+					strB = XmlUtil.SafeInnerXml(xn, "UrlOverride");
+					break;
+
+				case "/Configuration/MainWindow/EntryListColumnCollection/Column":
+					strA = XmlUtil.SafeInnerXml(xn, "Type");
+					strB = XmlUtil.SafeInnerXml(xn, "CustomName");
+					break;
+
+				case "/Configuration/PasswordGenerator/UserProfiles/Profile":
+					strA = XmlUtil.SafeInnerXml(xn, "Name");
+					break;
+
+				default: break;
+			}
+
+			Debug.Assert((strA == null) || (strA.IndexOf('<') < 0));
+			Debug.Assert((strB == null) || (strB.IndexOf('<') < 0));
+			Debug.Assert((strB == null) || (strA != null)); // B => A
+			Debug.Assert((strA == null) || (strA.Length != 0));
+
+			if(strB != null) return ((strA ?? string.Empty) + " <> " + strB);
+			return strA;
+		}
+
+		internal static string GetEmptyConfigXml()
+		{
+			return ("<?xml version=\"1.0\" encoding=\"utf-8\"?>\r\n" +
+				"<" + StrXmlTypeName + " xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\">\r\n" +
+				"\t<Meta />\r\n" +
+				"</" + StrXmlTypeName + ">");
+		}
 	}
 
 	[Flags]
