@@ -971,61 +971,7 @@ namespace KeePass.Forms
 
 		private void OnEntryAdd(object sender, EventArgs e)
 		{
-			PwGroup pg = GetSelectedGroup();
-			Debug.Assert(pg != null); if(pg == null) return;
-
-			if(pg.IsVirtual)
-			{
-				MessageService.ShowWarning(KPRes.GroupCannotStoreEntries,
-					KPRes.SelectDifferentGroup);
-				return;
-			}
-
-			PwDatabase pwDb = m_docMgr.ActiveDatabase;
-			PwEntry pwe = new PwEntry(true, true);
-			pwe.Strings.Set(PwDefs.UserNameField, new ProtectedString(
-				pwDb.MemoryProtection.ProtectUserName, pwDb.DefaultUserName));
-
-			ProtectedString psAutoGen = PwGeneratorUtil.GenerateAcceptable(
-				Program.Config.PasswordGenerator.AutoGeneratedPasswordsProfile,
-				null, pwe, pwDb, false);
-			pwe.Strings.Set(PwDefs.PasswordField, psAutoGen.WithProtection(
-				pwDb.MemoryProtection.ProtectPassword));
-
-			int nExpireDays = Program.Config.Defaults.NewEntryExpiresInDays;
-			if(nExpireDays >= 0)
-			{
-				pwe.Expires = true;
-				pwe.ExpiryTime = DateTime.UtcNow.AddDays(nExpireDays);
-			}
-
-			pwe.IconId = PwDefs.GroupIconToEntryIcon(pg.IconId);
-			pwe.CustomIconUuid = pg.CustomIconUuid;
-
-			// Temporarily assume that the entry is in pg; required for retrieving
-			// the default auto-type sequence
-			pwe.ParentGroup = pg;
-
-			PwEntryForm pForm = new PwEntryForm();
-			pForm.InitEx(pwe, PwEditMode.AddNewEntry, pwDb, m_ilCurrentIcons,
-				false, false);
-			if(UIUtil.ShowDialogAndDestroy(pForm) == DialogResult.OK)
-			{
-				pg.AddEntry(pwe, true);
-				UpdateUI(false, null, pwDb.UINeedsIconUpdate, null, true,
-					null, true, m_lvEntries);
-
-				PwObjectList<PwEntry> lSelect = new PwObjectList<PwEntry>();
-				lSelect.Add(pwe);
-				SelectEntries(lSelect, true, true);
-				EnsureVisibleSelected(false);
-				UpdateUIState(false);
-
-				if(Program.Config.Application.AutoSaveAfterEntryEdit)
-					SaveDatabase(pwDb, sender);
-			}
-			else UpdateUI(false, null, pwDb.UINeedsIconUpdate, null,
-				pwDb.UINeedsIconUpdate, null, false);
+			AddEntryEx(sender, null, null, null);
 		}
 
 		private void OnEntryEdit(object sender, EventArgs e)
@@ -2395,7 +2341,7 @@ namespace KeePass.Forms
 
 		private void OnTabMainSelectedIndexChanged(object sender, EventArgs e)
 		{
-			if(m_bBlockTabChanged) return;
+			if(m_uTabChangeBlocked != 0) return;
 
 			SaveWindowState();
 
