@@ -267,6 +267,7 @@ namespace KeePassLib.Serialization
 		public static readonly string WrhMoveFileTo = "MoveFileTo";
 
 		public static event EventHandler<IOAccessEventArgs> IOAccessPre;
+		public static event EventHandler<IOWebRequestEventArgs> IOWebRequestPre;
 
 #if !KeePassLibSD
 #if !KeePassUAP
@@ -365,6 +366,13 @@ namespace KeePassLib.Serialization
 			bool? ob = p.GetBool(IocKnownProperties.PreAuth);
 			if(ob.HasValue) request.PreAuthenticate = ob.Value;
 #endif
+
+			if(IOConnection.IOWebRequestPre != null)
+			{
+				IOWebRequestEventArgs e = new IOWebRequestEventArgs(request,
+					((ioc != null) ? ioc.CloneDeep() : null));
+				IOConnection.IOWebRequestPre(null, e);
+			}
 		}
 
 		internal static void ConfigureWebClient(WebClient wc)
@@ -545,13 +553,13 @@ namespace KeePassLib.Serialization
 			PrepareWebAccess(ioc);
 
 			IOWebClient wc = new IOWebClient(ioc);
-			ConfigureWebClient(wc);
 
 			if((ioc.UserName.Length > 0) || (ioc.Password.Length > 0))
 				wc.Credentials = new NetworkCredential(ioc.UserName, ioc.Password);
-			else if(NativeLib.IsUnix()) // Mono requires credentials
+			else if(MonoWorkarounds.IsRequired(688007))
 				wc.Credentials = new NetworkCredential("anonymous", string.Empty);
 
+			ConfigureWebClient(wc);
 			return wc;
 		}
 
@@ -560,13 +568,13 @@ namespace KeePassLib.Serialization
 			PrepareWebAccess(ioc);
 
 			WebRequest req = WebRequest.Create(ioc.Path);
-			ConfigureWebRequest(req, ioc);
 
 			if((ioc.UserName.Length > 0) || (ioc.Password.Length > 0))
 				req.Credentials = new NetworkCredential(ioc.UserName, ioc.Password);
-			else if(NativeLib.IsUnix()) // Mono requires credentials
+			else if(MonoWorkarounds.IsRequired(688007))
 				req.Credentials = new NetworkCredential("anonymous", string.Empty);
 
+			ConfigureWebRequest(req, ioc);
 			return req;
 		}
 
