@@ -204,6 +204,18 @@ namespace KeePass.Util
 
 			return ps;
 		}
+
+		internal static void GenerateAuto(PwEntry pe, PwDatabase pd)
+		{
+			if(pe == null) { Debug.Assert(false); return; }
+			if(pd == null) { Debug.Assert(false); return; }
+
+			ProtectedString ps = GenerateAcceptable(
+				Program.Config.PasswordGenerator.AutoGeneratedPasswordsProfile,
+				null, pe, pd, false);
+			pe.Strings.Set(PwDefs.PasswordField, ps.WithProtection(
+				pd.MemoryProtection.ProtectPassword));
+		}
 #endif
 	}
 }
